@@ -72,8 +72,8 @@ class ViewSet(object):
 
     def __init__(self, name=None, model=None, template_dir=None, exclude=None):
 
-        self.links = {"default": []}
-        self.instance_links = {"default": []}
+        self.links = {self.default_global_link: []}
+        self.instance_links = {self.default_instance_link: []}
 
         if exclude:
             self.exclude = exclude
@@ -94,16 +94,24 @@ class ViewSet(object):
         if self.base_url is None:
             self.base_url = "^%s/" % self.name
 
-        self.views = SortedDict((
-            ("create", (ViewSetCreateView, r'^create/$', [])),
-            ("update", (ViewSetUpdateView, r'^%supdate/$' % self.object_url, [])),
-            ("delete", (ViewSetDeleteView, r'^%sdelete/$' % self.object_url, [])),
-            ("detail", (ViewSetDetailView, r'^%s$' % self.object_url, [])),
-            ("list", (ViewSetListView, r'^$', [])),
-        ))
+        self.views = SortedDict()
 
-        for name in self.exclude:
-            del self.views[name]
+        for ordering, (name, view) in enumerate((
+            ("list", ViewSetListView),
+            ("create", ViewSetCreateView),
+            ("detail", ViewSetDetailView),
+            ("update", ViewSetUpdateView),
+            ("delete", ViewSetDeleteView)
+        )):
+            if name not in self.exclude:
+                if name in ("update", "delete", ):
+                    self.instance_view(name, ordering=ordering)(view)
+                elif name in ("list", ):
+                    self.register(name, url=r'^$', ordering=ordering, links=[])(view)
+                elif name in ("detail", ):
+                    self.register(name, url=r'^%s$' % self.object_url, links=[])(view)
+                else:
+                    self.register(name, ordering=ordering)(view)
 
         if template_dir:
             self.template_dir = template_dir
@@ -161,8 +169,6 @@ class ViewSet(object):
                 else:
                     self.links[link] = [view]
 
-            print(name, view, parents)
-
 #             view.name = name
 #             view.manager = self
             view = view.as_view(**kwargs)
@@ -203,9 +209,9 @@ class ViewSet(object):
 
         return inner
 
-    def instance_view(self, name, links=None):
+    def instance_view(self, name, ordering=0, links=None):
         return self.register(name,
-            r'^%s%s/$' % (self.object_url, name), links=links)
+            r'^%s%s/$' % (self.object_url, name), ordering=ordering, links=links)
 
     def extra_context(self, request, view, **kwargs):
         return dict(
